<?php
    /**
     * Created by PhpStorm.
     * User: stes
     * Date: 04.04.18
     * Time: 12:22
     */
    
    namespace backend\controllers;
    
    use artbox\core\admin\actions\Create;
    use artbox\core\admin\actions\Delete;
    use backend\actions\Index;
    use artbox\core\admin\actions\Update;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use artbox\core\admin\widgets\Form;
    use common\models\blog\Category;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;

    class BlogCategoryController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        public function actions()
        {
            return [
                'index'  => [
                    'class'            => Index::className(),
                    'columns'          => [
                        'title'      => [
                            'type' => Index::ACTION_COL,
                        ],
                        'parent' => [
                            'type'         => Index::RELATION_COL,
                            'columnConfig' => [
                                'relationField' => 'title',
                            ],
                        ],
                        'sort'       => [
                            'type' => Index::POSITION_COL,
                        ],
                        'status'    => [
                            'type' => Index::STATUS_COL,
                        ],
                    ],
                    'model'            => Category::className(),
                    'hasLanguage'      => true,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Category::className(),
                    'hasAlias'       => true,
                    'hasGallery'     => false,
                    'languageFields' => [
                        [
                            'name' => 'title',
                            'type' => Form::STRING,
                        ],
                        [
                            'name' => 'description',
                            'type' => Form::WYSIWYG,
                        ],
                    ],
                    'fields'         => [
                        [
                            'name' => 'image_id',
                            'type' => Form::IMAGE,
                        ],
                        [
                            'name'              => 'parent_id',
                            'type'              => Form::RELATION,
                            'relationAttribute' => 'title',
                            'relationName'      => 'parent',
                            'multiple'          => true,
                        ],
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
    
        public function findModel($id)
        {
            $model = Category::find()
                         ->with('languages')
                         ->where([ 'id' => $id ])
                         ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
    
        public function newModel()
        {
            return new Category();
        }
    
        public function deleteModel($id)
        {
            $category = Category::find()
                        ->with('languages.alias')
                        ->where(
                            [
                                'id' => $id,
                            ]
                        )
                        ->one();
            $langs = call_user_func(
                [
                    $category,
                    'getVariationModels',
                ]
            );
            foreach ($langs as $lang) {
                if ($lang->alias !== null) {
                    $lang->alias->delete();
                }
            }
        
            return $category->delete();
        }
    
        protected static function fieldsConfig()
        {
            return [
                'model'          => Category::className(),
                'hasAlias'       => true,
                'hasGallery'     => false,
                'languageFields' => [
                    [
                        'name' => 'title',
                        'type' => Form::STRING,
                    ],
                    [
                        'name' => 'description',
                        'type' => Form::WYSIWYG,
                    ],
                ],
                'fields'         => [
                
                    [
                        'name' => 'image_id',
                        'type' => Form::IMAGE,
                    ],
                    [
                        'name'              => 'parent_id',
                        'type'              => Form::RELATION,
                        'relationAttribute' => 'title',
                        'relationName'      => 'parent',
                        'multiple'          => true,
                    ],
                    [
                        'name' => 'status',
                        'type' => Form::BOOL,
                    ],
                    [
                        'name' => 'sort',
                        'type' => Form::NUMBER,
                    ],
                ],
            ];
        }
    }