<?php
    /**
     * Created by PhpStorm.
     * User: stes
     * Date: 04.04.18
     * Time: 12:42
     */
    
    namespace backend\controllers;
    
    use artbox\core\admin\actions\Create;
    use artbox\core\admin\actions\Delete;
    use backend\actions\Index;
    use artbox\core\admin\actions\Update;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use artbox\core\admin\widgets\Form;
    use common\models\blog\Tag;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;

    class BlogTagController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        public function actions()
        {
            return [
                'index'  => [
                    'class'            => Index::className(),
                    'columns'          => [
                        'label'      => [
                            'type' => Index::ACTION_COL,
                        ],
                        'sort'      => [
                            'type' => Index::POSITION_COL,
                        ],
                    ],
                    'model'            => Tag::className(),
                    'hasLanguage'      => true,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Tag::className(),
                    'hasAlias'       => true,
                    'hasGallery'     => false,
                    'languageFields' => [
                        [
                            'name' => 'title',
                            'type' => Form::STRING,
                        ]
                    ],
                    'fields'         => [
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
    
        public function findModel($id)
        {
            $model = Tag::find()
                             ->with('languages')
                             ->where([ 'id' => $id ])
                             ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
    
        public function newModel()
        {
            return new Tag();
        }
    
        public function deleteModel($id)
        {
            $category = Tag::find()
                                ->with('languages.alias')
                                ->where(
                                    [
                                        'id' => $id,
                                    ]
                                )
                                ->one();
            $langs = call_user_func(
                [
                    $category,
                    'getVariationModels',
                ]
            );
            foreach ($langs as $lang) {
                if ($lang->alias !== null) {
                    $lang->alias->delete();
                }
            }
        
            return $category->delete();
        }
    
        protected static function fieldsConfig()
        {
            return [
                'model'          => Tag::className(),
                'hasAlias'       => true,
                'hasGallery'     => false,
                'languageFields' => [
                    [
                        'name' => 'label',
                        'type' => Form::STRING,
                    ]
                ],
                'fields'         => [
                    [
                        'name' => 'sort',
                        'type' => Form::NUMBER,
                    ],
                ],
            ];
        }
    }