<?php
    /**
     * Created by PhpStorm.
     * User: stes
     * Date: 12.09.18
     * Time: 16:39
     */
    
    namespace backend\controllers;
    
    use artbox\core\admin\actions\Delete;
    use artbox\core\admin\actions\Index;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use backend\actions\Create;
    use backend\actions\Update;
    use backend\widgets\Form;
    use common\models\Logo;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;

    class LogoController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        public function actions()
        {
            return [
                'index'  => [
                    'class'            => Index::className(),
                    'columns'          => [
                        'link'      => [
                            'type' => Index::ACTION_COL,
                        ],
                        'sort'       => [
                            'type' => Index::POSITION_COL,
                        ],
                    ],
                    'model'            => Logo::className(),
                    'hasLanguage'      => false,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Logo::className(),
                    'hasAlias'       => true,
                    'hasGallery'     => true,
                    'fields'         => [
                        [
                            'name' => 'image_id',
                            'type' => Form::IMAGE,
                        ],
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
    
        public function findModel($id)
        {
            $model = Logo::find()
                            ->where([ 'id' => $id ])
                            ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
    
        public function newModel()
        {
            return new Logo();
        }
    
        public function deleteModel($id)
        {
            $page = Logo::find()
                           ->where(
                               [
                                   'id' => $id,
                               ]
                           )
                           ->one();
        
            return $page->delete();
        }
    
        protected static function fieldsConfig()
        {
            return [
                'model'          => Logo::className(),
                'hasAlias'       => false,
                'hasGallery'     => false,
                'languageFields' => [
                ],
                'fields'         => [
    
                    [
                        'name' => 'image_id',
                        'type' => Form::IMAGE,
                    ],
                    [
                        'name' => 'sort',
                        'type' => Form::NUMBER,
                    ],
                    [
                        'name' => 'link',
                        'type' => Form::STRING,
                    ],
                ],
            ];
        }
    }