<?php
    
    namespace backend\controllers;
    
    use function array_merge;
    use artbox\core\admin\actions\Create;
    use artbox\core\admin\actions\Delete;
    use backend\actions\Index;
    use artbox\core\admin\actions\Update;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use artbox\core\admin\widgets\Form;
    use common\models\partners\Partner;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;
    
    class PartnerController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        public function actions()
        {
            return [
                'index'  => [
                    'class'            => Index::className(),
                    'columns'          => [
                        'title'      => [
                            'type' => Index::ACTION_COL,
                        ],
                        'sort'       => [
                            'type' => Index::POSITION_COL,
                        ],
                        'status'    => [
                            'type' => Index::STATUS_COL,
                        ],
                    ],
                    'model'            => Partner::className(),
                    'hasLanguage'      => true,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Partner::className(),
                    'hasAlias'       => true,
                    'hasGallery'     => true,
                    'languageFields' => [
                        [
                            'name' => 'title',
                            'type' => Form::STRING,
                        ],
                        [
                            'name' => 'description',
                            'type' => Form::WYSIWYG,
                        ],

                    ],
                    'fields'         => [
                        [
                            'name' => 'image_id',
                            'type' => Form::IMAGE,
                        ],
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
        
        public function findModel($id)
        {
            $model = Partner::find()
                            ->with('languages')
                            ->where([ 'id' => $id ])
                            ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
        
        public function newModel()
        {
            return new Partner();
        }
        
        public function deleteModel($id)
        {
            $page = Partner::find()
                           ->with('languages')
                           ->where(
                            [
                                'id' => $id,
                            ]
                        )
                           ->one();
            
            return $page->delete();
        }
        
        protected static function fieldsConfig()
        {
            return [
                'model'          => Partner::className(),
                'hasAlias'       => false,
                'hasGallery'     => false,
                'languageFields' => [
                    [
                        'name' => 'title',
                        'type' => Form::STRING,
                    ],
                    [
                        'name' => 'description',
                        'type' => Form::TEXTAREA,
                    ],


                ],
                'fields'         => [
                    
                    [
                        'name' => 'image_id',
                        'type' => Form::IMAGE,
                    ],
                    [
                        'name' => 'status',
                        'type' => Form::BOOL,
                    ],
                    [
                        'name' => 'sort',
                        'type' => Form::NUMBER,
                    ],
                ],
            ];
        }
        
        public function actionSettings()
        {
            return $this->render('settings');
        }
    }