<?php
    
    namespace backend\controllers;
    
    use function array_merge;
    use artbox\core\admin\actions\Create;
    use artbox\core\admin\actions\Delete;
    use backend\actions\Index;
    use artbox\core\admin\actions\Update;
    use artbox\core\admin\actions\View;
    use artbox\core\admin\interfaces\ControllerInterface;
    use artbox\core\admin\widgets\Form;
    use common\models\speaker\Speaker;
    use yii\filters\AccessControl;
    use yii\filters\VerbFilter;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;
    
    class SpeakerController extends Controller implements ControllerInterface
    {
        public function behaviors()
        {
            return [
                'verbs'  => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'delete' => [ 'POST' ],
                    ],
                ],
                'access' => [
                    'class' => AccessControl::className(),
                    'rules' => [
                        [
                            'allow' => true,
                            'roles' => [ '@' ],
                        ],
                    ],
                ],
            ];
        }
        public function actions()
        {
            return [
                'index'  => [
                    'class'            => Index::className(),
                    'columns'          => [
                        'name'      => [
                            'type' => Index::ACTION_COL,
                        ],
                        'sort'       => [
                            'type' => Index::POSITION_COL,
                        ],
                        'status'    => [
                            'type' => Index::STATUS_COL,
                        ],
                    ],
                    'model'            => Speaker::className(),
                    'hasLanguage'      => true,
                    'enableMassDelete' => true,
                    'modelPrimaryKey'  => 'id',
                ],
                'create' => array_merge([ 'class' => Create::className() ], self::fieldsConfig()),
                'update' => array_merge([ 'class' => Update::className() ], self::fieldsConfig()),
                'view'   => [
                    'class'          => View::className(),
                    'model'          => Speaker::className(),
                    'hasAlias'       => true,
                    'hasGallery'     => true,
                    'languageFields' => [
                        [
                            'name' => 'title',
                            'type' => Form::STRING,
                        ],
                        [
                            'name' => 'body',
                            'type' => Form::WYSIWYG,
                        ],
	                    [
		                    'name' => 'text1',
		                    'type' => Form::WYSIWYG,
	                    ],
                    ],
                    'fields'         => [
                        [
                            'name' => 'image_id',
                            'type' => Form::IMAGE,
                        ],
                    ],
                ],
                'delete' => [
                    'class' => Delete::className(),
                ],
            ];
        }
        
        public function findModel($id)
        {
            $model = Speaker::find()
                            ->with('languages')
                            ->where([ 'id' => $id ])
                            ->one();
            if ($model !== null) {
                return $model;
            } else {
                throw new NotFoundHttpException('The requested page does not exist.');
            }
        }
        
        public function newModel()
        {
            return new Speaker();
        }
        
        public function deleteModel($id)
        {
            $page = Speaker::find()
                           ->with('languages')
                           ->where(
                            [
                                'id' => $id,
                            ]
                        )
                           ->one();
            
            return $page->delete();
        }
        
        protected static function fieldsConfig()
        {
            return [
                'model'          => Speaker::className(),
                'hasAlias'       => false,
                'hasGallery'     => false,
                'languageFields' => [
                    [
                        'name' => 'name',
                        'type' => Form::STRING,
                    ],
                    [
                        'name' => 'position',
                        'type' => Form::TEXTAREA,
                    ],
	                [
		                'name' => 'text1',
		                'type' => Form::WYSIWYG,
	                ],
                    [
                        'name' => 'organization',
                        'type' => Form::TEXTAREA,
                    ],
                ],
                'fields'         => [
                    
                    [
                        'name' => 'image_id',
                        'type' => Form::IMAGE,
                    ],
                    [
                        'name' => 'status',
                        'type' => Form::BOOL,
                    ],
                    [
                        'name' => 'sort',
                        'type' => Form::NUMBER,
                    ],
                ],
            ];
        }
        
        public function actionSettings()
        {
            return $this->render('settings');
        }
    }