<?php
    
    namespace backend\widgets;
    
    use artbox\core\admin\assets\DateRangePicker;
    use artbox\core\admin\assets\Switchery;
    use artbox\core\admin\widgets\ImageInput;
    use artbox\core\helpers\SlugifyDecorator;
    use artbox\core\models\Language;
    use artbox\core\services\Languages;
    use artbox\core\widgets\GalleryWidget;
    use function call_user_func;
    use dosamigos\tinymce\TinyMce;
    use kartik\select2\Select2;
    use mihaildev\ckeditor\CKEditor;
    use yii\base\InvalidConfigException;
    use yii\base\Widget;
    use yii\db\ActiveRecord;
    use yii\helpers\ArrayHelper;
    use yii\helpers\Html;
    use yii\widgets\ActiveForm;
    
    /**
     * Render inputs to create or save ActiveRecord model with all relational models
     *
     * @package artbox\core\admin\widgets
     */
    class Form extends Widget
    {
        /**
         * Generates WYSIWYG redactor
         *
         * @see TinyMce, https://www.tinymce.com/
         */
        const WYSIWYG = 'wysiwyg';
        
        /**
         * Generates text input
         */
        const STRING = 'string';
        
        /**
         * Generates textarea
         */
        const TEXTAREA = 'textarea';
        
        /**
         * Generates checkbox
         */
        const BOOL = 'boolean';
        
        /**
         * Generates simple number input type
         */
        const NUMBER = 'number';
        
        /**
         * Generates select2 widget
         */
        const RELATION = 'relation';
        
        /**
         * Generates one image input
         */
        const IMAGE = 'image';
        
        /**
         * Generates Gallery widget
         *
         * @see GalleryWidget, \artbox\core\behaviors\GalleryBehavior
         */
        const GALLERY = 'gallery';
        
        /**
         *
         */
        const DATE = 'date';
    
        /**
         * generate select
         */
        const SELECT = 'select';
        /**
         * @var \artbox\core\admin\actions\Save
         */
        public $action;
        
        /**
         * @var Languages
         */
        protected $languages;
        
        /**
         * @var \yii\db\ActiveRecord
         */
        public $model;
        
        /**
         * Template for 1 language tab
         *
         * @var string
         */
        public $langTabTemplate = '<div class="style tabs-lang" style="display: {display};"><div class="style title-edit-page">{title}</div>{tab}</div>';
        
        /**
         * Template for block of all languages tabs
         *
         * @var string
         */
        public $langBlockTemplate = '<div class="x_panel x_panel-scroll tabs-lang-wr">{tabs}</div>';
        /**
         * @var array fields for seo value
         */
        public $decorateField = [];
        /**
         * @inheritdoc
         * @todo Remove H1 stabs
         * @return string|void
         * @throws \Exception
         * @throws \yii\base\InvalidConfigException
         */
        public function run()
        {
            Switchery::register($this->view);
            
            $js = <<< JS
$('.switchery').each(function(idx, elem) {
  new Switchery(elem, {
    color:'#46b749',
    secondaryColor:'#e2e2e2'
  });
});
JS;
            
            
            $this->languages = new Languages();
            
            $this->view->registerJs($js, \yii\web\View::POS_READY);
            $notify = <<<JS
    $('form').on('afterValidate', function(form, attribute, messages){
        if (messages.length > 0){
        new PNotify({
                        title: 'Info',
                        text: 'Проверьте заполнение полей',
                        type: 'info',
                        styling: "bootstrap3"
                    });
        }
    });
JS;
    
            $this->view->registerJs($notify, \yii\web\View::POS_READY);
            
            $form = ActiveForm::begin();
            if (!empty($this->action->languageFields)) {
                echo str_replace(
                    [
                        '{tabs}',
                        '{title}',
                    ],
                    [
                        $this->generateLangBlock($form),
                        'Языковой блок',
                    ],
                    $this->langBlockTemplate
                );
            }
            
            echo '<div class="x_panel x_panel-scroll">';
            
            echo '<div class="wrapp-blocks-edit-page columns-2">';
            echo '<div class="style title-edit-page">Основной блок</div>';
            $this->generateCommonBlock($form);
            echo '</div>';
            
            echo '</div>';
            
            if ($this->action->hasAlias) {
                echo str_replace(
                    [
                        '{tabs}',
                        '{title}',
                    ],
                    [
                        $this->generateAliasBlock($form),
                        'Seo блок',
                    ],
                    $this->langBlockTemplate
                );
            }
            
            if ($this->action->hasGallery) {
                echo '<div class="x_panel x_panel-scroll">';
                echo '<div class="wrapp-blocks-edit-page">';
                echo '<div class="style title-edit-page">Галерея</div>';
                echo GalleryWidget::widget(
                    [
                        'model' => $this->model,
                    ]
                );
                echo '</div>';
                echo '</div>';
            }
            
            echo '<div class="style buttons-page-wr">';
            echo Html::submitButton(
                \Yii::t('core', 'Save'),
                [
                    'class' => 'btn btn-success',
                ]
            );
            echo '</div>';
            
            $form::end();
            
            $this->registerClientScripts();
        }
        
        protected function registerClientScripts()
        {
            $js = <<<JS
 $(document)
        .on('click', '.pos-minus-adm', function(e) {
            e.preventDefault();
            var input = $(this)
                .parent()
                .find('input');
            var newVal = parseInt(input.val()) - 1;
            if (newVal > 0) {
                input.val(newVal);
            }
        });
    $(document)
        .on('click', '.pos-pluse-adm', function(e) {
            e.preventDefault();
            var input = $(this)
                .parent()
                .find('input');
            var newVal = parseInt((input.val() === '' ? 0 : input.val())) + 1;
            input.val(newVal);
        });
    
    $('#page-sort').keypress(function(e) {
      var symbol = (e.which) ? e.which : e.keyCode;
                        if (symbol < 48 || symbol > 57) {
                            return false;
                        }
    })
JS;
            
            $this->view->registerJs($js, \yii\web\View::POS_READY);
        }
        
        /**
         * If model has languages
         *
         * @param \yii\widgets\ActiveForm $form
         *
         * @return  string
         * @throws \yii\base\InvalidConfigException
         */
        protected function generateLangBlock(ActiveForm $form): string
        {
            $tabs = '';
            $i = 1;
            foreach ($this->getVariationModels() as $index => $variationModel) {
                $tab = '';
                foreach ($this->action->languageFields as $languageField) {
                    switch ($languageField[ 'type' ]) {
                        case self::STRING:
                            if (isset($languageField[ 'decorate' ]) and $languageField[ 'decorate' ]) {
                                $this->decorateField[ $index ] = $form->field(
                                    $variationModel,
                                    '[' . $index . ']' . $languageField[ 'name' ]
                                )
                                                                      ->label(
                                                                          self::getLanguageLabel(
                                                                              $variationModel,
                                                                              $languageField[ 'name' ],
                                                                              $variationModel->language_id
                                                                          )
                                                                      );
                                $tab .= $this->decorateField[ $index ];
                            } else {
                                $tab .= $form->field($variationModel, '[' . $index . ']' . $languageField[ 'name' ])
                                             ->label(
                                                 self::getLanguageLabel(
                                                     $variationModel,
                                                     $languageField[ 'name' ],
                                                     $variationModel->language_id
                                                 )
                                             );
                            }
                            break;
                        case self::TEXTAREA:
                            $tab .= $form->field($variationModel, '[' . $index . ']' . $languageField[ 'name' ])
                                         ->textarea(
                                             [
                                                 'rows' => 6,
                                             ]
                                         )
                                         ->label(
                                             self::getLanguageLabel(
                                                 $variationModel,
                                                 $languageField[ 'name' ],
                                                 $variationModel->language_id
                                             )
                                         );
                            break;
                        case self::IMAGE:
                            $tab .= $form->field(
                                $variationModel,
                                '[' . $index . ']' . $languageField[ 'name' ],
                                [ 'options' => [ 'class' => 'form-group filed-upload-imgs' ] ]
                            )
                                         ->widget(
                                             ImageInput::className(),
                                             [
                                                 'showPreview' => true,
                                             ]
                                         )
                                         ->label(
                                             self::getLanguageLabel(
                                                 $variationModel,
                                                 $languageField[ 'name' ],
                                                 $variationModel->language_id
                                             )
                                         );
                            break;
                        case self::WYSIWYG:
                            $tab .= $form->field($variationModel, '[' . $index . ']' . $languageField[ 'name' ])
                                         ->widget(
                                             TinyMce::className(),
                                             $this->action->getTinyMceConfig()
                                         )
                                         ->label(
                                             self::getLanguageLabel(
                                                 $variationModel,
                                                 $languageField[ 'name' ],
                                                 $variationModel->language_id
                                             )
                                         );
                            break;
                        default:
                            throw new InvalidConfigException(
                                \Yii::t(
                                    'core',
                                    'Unavailable or unknown type: {type}',
                                    [
                                        'type' => $languageField[ 'type' ],
                                    ]
                                )
                            );
                    }
                }
                
                if ($variationModel->language_id === $this->languages->getDefault()->id) {
                    $tabs .= str_replace(
                        [
                            '{tab}',
                            '{display}',
                        ],
                        [
                            $tab,
                            'block',
                        ],
                        $this->langTabTemplate
                    );
                } else {
                    $tabs .= str_replace(
                        [
                            '{tab}',
                            '{display}',
                        ],
                        [
                            $tab,
                            'none',
                        ],
                        $this->langTabTemplate
                    );
                }
                
                $i++;
            }
            
            return $tabs;
        }
        
        /**
         * Common block
         *
         * @param \yii\widgets\ActiveForm $form
         *
         * @throws \yii\base\InvalidConfigException
         */
        protected function generateCommonBlock(ActiveForm $form)
        {
            foreach ($this->action->fields as $field) {
                switch ($field[ 'type' ]) {
                    case self::STRING:
                        echo $form->field($this->model, $field[ 'name' ]);
                        break;
                    case self::TEXTAREA:
                        echo $form->field($this->model, $field[ 'name' ])
                                  ->textarea(
                                      [
                                          'rows' => 6,
                                      ]
                                  );
                        break;
                    case self::WYSIWYG:
                        echo $form->field($this->model, $field[ 'name' ])
                                  ->widget(
                                      TinyMce::className(),
                                      $this->action->getTinyMceConfig()
                                  );
                        break;
                    case self::BOOL:
                        echo $form->field(
                            $this->model,
                            $field[ 'name' ],
                            [
                                'template' => "<div class='div_ style' style='margin-bottom: 10px;'>{label}</div>\n{input}\n{error}",
                            ]
                        )
                                  ->checkbox(
                                      [
                                          'class' => 'switchery',
                                      ],
                                      false
                                  );
                        break;
                    case self::NUMBER:
                        echo $form->field(
                            $this->model,
                            $field[ 'name' ],
                            [
                                'template' => '{label}<span class="pos-minus-adm"></span>{input}<span class="pos-pluse-adm"></span>
                            {error}{hint}',
                                'options'  => [ 'class' => 'form-group filed-sort' ],
                            ]
                        );
                        break;
                    case self::RELATION:
                        $isMultiple = $field[ 'multiple' ] ?? false;
                        echo $form->field($this->model, $field[ 'name' ])
                                  ->widget(
                                      Select2::classname(),
                                      [
                                          'data'          => $this->action->relationalData[ $field[ 'name' ] ],
                                          'options'       => [
                                              'placeholder' => \Yii::t('core', 'Select ...'),
                                              'multiple'    => $isMultiple,
                                          ],
                                          'pluginOptions' => [
                                              'allowClear' => true,
                                          ],
                                      ]
                                  );
                        break;
                    case self::SELECT:
                        $isMultiple = $field[ 'multiple' ] ?? false;
                        echo $form->field($this->model, $field[ 'name' ])
                                  ->widget(
                                      Select2::classname(),
                                      [
                                          'data'          => $field['data'],
                                          'options'       => [
                                              'placeholder' => \Yii::t('core', 'Select ...'),
                                              'multiple'    => $isMultiple,
                                          ],
                                          'pluginOptions' => [
                                              'allowClear' => true,
                                          ],
                                      ]
                                  );
                        
                        break;
                    case self::IMAGE:
                        echo $form->field(
                            $this->model,
                            $field[ 'name' ],
                            [ 'options' => [ 'class' => 'form-group filed-upload-imgs' ] ]
                        )
                                  ->widget(
                                      ImageInput::className(),
                                      [
                                          'showPreview' => true,
                                      ]
                                  );
                        break;
                    case self::DATE:
                        DateRangePicker::register($this->view);
                        $mindate = date("d-m-Y H:i");
                        $value = $this->model->{$field['name']};
                        $js = <<< JS
var dateRangeInputFrom = $('#date_field');
var dateFormat = '{$this->model->clientDateFormat}';
dateRangeInputFrom.daterangepicker({
  singleDatePicker: true,
      autoUpdateInput: true,
       showDropdowns: true,
       minDate: '{$mindate}',
       timePicker: true,
       timePicker24Hour: true,
      locale: {
         cancelLabel: 'Clear',
          format: dateFormat
      }
}, function(){
      
      });
dateRangeInputFrom.on('cancel.daterangepicker', function(ev, picker) {
  //do something, like clearing an input
  dateRangeInputFrom.val('');
});
if ("{$value}" == ""){
     dateRangeInputFrom.val('');
}
JS;
                        $this->view->registerJs($js, \yii\web\View::POS_READY);
                        echo $form->field(
                            $this->model,
                            $field[ 'name' ],
                            [ 'options' => [ 'class' => 'form-group date-search' ] ]
                        )->textInput(['id' => "date_field"]);
                        break;
                        
                    default:
                        throw new InvalidConfigException(
                            \Yii::t(
                                'core',
                                'Unavailable or unknown type: {type}',
                                [
                                    'type' => $field[ 'type' ],
                                ]
                            )
                        );
                }
            }
        }
        
        /**
         * Generate seo block
         *
         * @param \yii\widgets\ActiveForm $form
         *
         * @return string
         */
        protected function generateAliasBlock(ActiveForm $form)
        {
            $tabs = '';
            $i = 1;
            foreach ($this->getAliases() as $index => $alias) {
                $tab = '';
                if (isset($this->decorateField[ $index ])) {
                    $tab .= '<div class="seo-btns-wr">' . SlugifyDecorator::decorate(
                            $form->field($alias, "[$index]value"),
                            [ '/seo/alias/slugify' ],
                            $this->decorateField[ $index ],
                            false,
                            $alias->language_id
                        )
                                                                          ->textInput(
                                                                              [ 'maxlength' => true ]
                                                                          ) . "</div>";
                } else {
                    $tab .= $form->field($alias, '[' . $index . ']value')
                                 ->label(
                                     self::getLanguageLabel($alias, 'value', $alias->language_id)
                                 );
                }
                
                $tab .= $form->field($alias, '[' . $index . ']title')
                             ->label(
                                 self::getLanguageLabel($alias, 'title', $alias->language_id)
                             );
                
                $tab .= $form->field($alias, '[' . $index . ']description')
                             ->textarea(
                                 [
                                     'rows' => 6,
                                 ]
                             )
                             ->label(
                                 self::getLanguageLabel($alias, 'description', $alias->language_id)
                             );
                
                $tab .= $form->field($alias, '[' . $index . ']h1')
                             ->label(
                                 self::getLanguageLabel($alias, 'h1', $alias->language_id)
                             );
                
                $tab .= $form->field($alias, '[' . $index . ']seo_text')
                             ->widget(
                                 TinyMce::className(),
                                 $this->action->getTinyMceConfig()
                             )
                             ->label(
                                 self::getLanguageLabel($alias, 'seo_text', $alias->language_id)
                             );
                
                $tab .= $form->field($alias, '[' . $index . ']robots')
                             ->widget(
                                 Select2::class,
                                 [
                                     'data' => [
                                         'index, follow'     => 'index, follow',
                                         'index, nofollow'   => 'index, nofollow',
                                         'noindex, follow'   => 'noindex, follow',
                                         'noindex, nofollow' => 'noindex, nofollow',
                                     ],
                                 ]
                             )
                             ->label(
                                 self::getLanguageLabel($alias, 'robots', $alias->language_id)
                             );
                
                if ($alias->language_id === $this->languages->getDefault()->id) {
                    $tabs .= str_replace(
                        [
                            '{tab}',
                            '{display}',
                        ],
                        [
                            $tab,
                            'block',
                        ],
                        $this->langTabTemplate
                    );
                } else {
                    $tabs .= str_replace(
                        [
                            '{tab}',
                            '{display}',
                        ],
                        [
                            $tab,
                            'none',
                        ],
                        $this->langTabTemplate
                    );
                }
                
                $i++;
            }
            
            return $tabs;
        }
        
        /**
         * Appends language short name to label
         *
         * @param \yii\db\ActiveRecord $model
         * @param string               $field
         * @param                      $language_id
         *
         * @return string
         */
        protected static function getLanguageLabel(ActiveRecord $model, string $field, $language_id): string
        {
            $languages = Language::getActive();
            return $model->getAttributeLabel(
                    $field
                ) . ' (' . $languages[ $language_id ]->url . ')';
            
        }
        
        /**
         * @return ActiveRecord[]
         */
        protected function getVariationModels(): array
        {
            return call_user_func(
                [
                    $this->model,
                    'getVariationModels',
                ]
            );
        }
        
        /**
         * @return \artbox\core\models\Alias[]
         */
        protected function getAliases(): array
        {
            return call_user_func(
                [
                    $this->model,
                    'loadAliases',
                ]
            );
        }
    }

?>



