<?php
    namespace common\models;

    use artbox\order\models\Customer;
    use Yii;
    use yii\base\Model;

    /**
     * Login form
     */
    class LoginForm extends Model
    {
        public $username;
        public $password;
        public $rememberMe = true;
        public $returnUrl;
    
        private $_user;
    
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                // username and password are both required
                [
                    [
                        'username',
                        'password',
                    ],
                    'required',
                ],
                [
                    [
                        'returnUrl',
                    ],
                    'string',
                ],
                // rememberMe must be a boolean value
                [
                    'rememberMe',
                    'boolean',
                ],
                // password is validated by validatePassword()
                [
                    'password',
                    'validatePassword',
                ],
            ];
        }
    
        /**
         * Validates the password.
         * This method serves as the inline validation for password.
         *
         * @param string $attribute the attribute currently being validated
         * @param array  $params    the additional name-value pairs given in the rule
         */
        public function validatePassword($attribute, $params)
        {
            if (!$this->hasErrors()) {
                $user = $this->getUser();
                if (!$user || !$user->validatePassword($this->password)) {
                    $this->addError($attribute, 'Incorrect username or password.');
                }
            }
        }
    
        /**
         * Logs in a user using the provided username and password.
         *
         * @return bool whether the user is logged in successfully
         */
        public function login()
        {
            if ($this->validate()) {
                return Yii::$app->user->login($this->getUser(), $this->rememberMe ? 3600 * 24 * 30 : 0);
            } else {
                return false;
            }
        }
    
        /**
         * Finds user by [[username]]
         *
         * @return Customer|null
         */
        protected function getUser()
        {
            if ($this->_user === null) {
                $this->_user = Customer::findByUsername($this->username);
            }
    
            return $this->_user;
        }
    
        public function attributeLabels()
        {
            return [
                'username'      =>  Yii::t('app', 'Логин'),
                'password'      =>  Yii::t('app', 'Пароль'),
                'rememberMe'    =>  Yii::t('app', 'Запомнить'),
            ];
        }
    }
