<?php
    
    namespace common\models\blog;
    
    use artbox\core\models\traits\AliasableTrait;
    use yii\db\ActiveRecord;
    use artbox\core\models\Language;
    use yii\db\ActiveQuery;
    use yii\helpers\Json;
    use yii2tech\ar\position\PositionBehavior;
    use yii2tech\ar\variation\VariationBehavior;
    
    /**
     * This is the model class for table "blog_tag".
     *
     * @property integer    $id
     * @property Article[]  $articles
     * @property TagLang[]  $blogTagLangs
     * @property Language[] $languages
     * *  * from VariationBehavior
     * @method ActiveQuery  hasDefaultVariationRelation();
     */
    class Tag extends ActiveRecord
    {
        use AliasableTrait;
        /**
         * @inheritdoc
         */
        public static function tableName()
        {
            return 'blog_tag';
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'translations'     => [
                    'class'                             => VariationBehavior::className(),
                    'variationsRelation'                => 'languages',
                    'defaultVariationRelation'          => 'language',
                    'variationOptionReferenceAttribute' => 'language_id',
                    'optionModelClass'                  => Language::className(),
                    'defaultVariationOptionReference'   => function () {
                        return Language::getCurrent()->id;
                    },
                    'optionQueryFilter'                 => function (ActiveQuery $query) {
                        $query->where(
                            [
                                'status' => true,
                            ]
                        );
                    },
                ],
                'positionBehavior' => [
                    'class'             => PositionBehavior::className(),
                    'positionAttribute' => 'sort',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function rules()
        {
            return [
                [
                    [
                        'id',
                        'sort',
                    ],
                    'integer',
                ],
            ];
        }
        public function getRoute()
        {
            return Json::encode(
                [
                    'blog/tag',
                    'id' => $this->id,
                ]
            );
        }
        
        /**
         * @inheritdoc
         */
        public function attributeLabels()
        {
            return [
                'id'    => 'ID',
                'label' => \Yii::t('core', 'Label'),
                'sort'  => \Yii::t('core', 'Sort'),
            ];
        }
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(TagLang::className(), [ 'blog_tag_id' => 'id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasDefaultVariationRelation();
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getArticles()
        {
            return $this->hasMany(Article::className(), [ 'id' => 'blog_article_id' ])
                        ->viaTable('blog_article_to_tag', [ 'blog_tag_id' => 'id' ]);
        }
    }
