<?php
    
    namespace common\models\page;
    
    use artbox\core\models\Language;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii2tech\ar\position\PositionBehavior;
    use yii2tech\ar\variation\VariationBehavior;

    /**
     * Class Category
     *
     * @package common\models\page
     * from VariationBehavior
     * @method ActiveQuery  hasDefaultVariationRelation();
     */
    class Category extends ActiveRecord
    {
        public function rules()
        {
            return [
                [
                    [ 'sort' ],
                    'integer',
                ],
                [
                    [ 'status' ],
                    'boolean',
                ],
            ];
        }
        
        public function behaviors()
        {
            return [
                'translations' => [
                    'class'                             => VariationBehavior::className(),
                    'variationsRelation'                => 'languages',
                    'defaultVariationRelation'          => 'language',
                    'variationOptionReferenceAttribute' => 'language_id',
                    'optionModelClass'                  => Language::className(),
                    'defaultVariationOptionReference'   => function () {
                        return Language::getCurrent()->id;
                    },
                    'optionQueryFilter'                 => function (ActiveQuery $query) {
                        $query->where(
                            [
                                'status' => true,
                            ]
                        );
                    },
                ],
                'positionBehavior'     => [
                    'class'             => PositionBehavior::className(),
                    'positionAttribute' => 'sort',
                ],
            ];
        }
        
        public static function tableName()
        {
            return 'page_category';
        }
    
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(CategoryLang::className(), [ 'page_category_id' => 'id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasDefaultVariationRelation();
        }
        
        public function attributeLabels()
        {
            return [
                'title'  => \Yii::t('core', 'Title'),
                'status' => \Yii::t('core', 'Status'),
                'sort'   => \Yii::t('core', 'Sort'),
            ];
        }
        public function getPages(){
            return $this->hasMany(Page::className(), [ 'id' => 'page_id' ])
                        ->viaTable('page_to_category', [ 'category_id' => 'id' ]);
        }
        
        public function getParent()
        {
            return $this->hasOne(Category::className(), [ 'id' => 'parent_id' ]);
        }
    }