<?php
    
    namespace common\models\page;
    
    use artbox\core\behaviors\GalleryBehavior;
    use artbox\core\models\Image;
    use artbox\core\models\Language;
    use artbox\core\models\traits\AliasableTrait;
    use yii\behaviors\TimestampBehavior;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii\helpers\Json;
    use yii2tech\ar\linkmany\LinkManyBehavior;
    use yii2tech\ar\position\PositionBehavior;
    use yii2tech\ar\variation\VariationBehavior;

    /**
     * Class Page
     *
     * @package common\models\page
     *
     * from VariationBehavior
     * @method ActiveQuery  hasDefaultVariationRelation();
     */
    class Page extends ActiveRecord
    {
        use AliasableTrait;
        
        public function rules()
        {
            return [
                [
                    [
                        'updated_at',
                    ],
                    'integer',
                ],
                [
                    [
                        'sort',
                        'image_id',
                    ],
                    'integer',
                ],
                [
                    [
                        'in_menu',
                    ],
                    'boolean',
                ],
                [
                    'categoryIds',
                    'safe',
                ],
            ];
        }
        
        public function behaviors()
        {
            return [
                'translations'         => [
                    'class'                             => VariationBehavior::className(),
                    'variationsRelation'                => 'languages',
                    'defaultVariationRelation'          => 'language',
                    'variationOptionReferenceAttribute' => 'language_id',
                    'optionModelClass'                  => Language::className(),
                    'defaultVariationOptionReference'   => function () {
                        return Language::getCurrent()->id;
                    },
                    'optionQueryFilter'                 => function (ActiveQuery $query) {
                        $query->where(
                            [
                                'status' => true,
                            ]
                        );
                    },
                ],
                'positionBehavior'     => [
                    'class'             => PositionBehavior::className(),
                    'positionAttribute' => 'sort',
                ],
                'linkCategoryBehavior' => [
                    'class'                      => LinkManyBehavior::className(),
                    'relation'                   => 'categories',
                    'relationReferenceAttribute' => 'categoryIds',
                ],
                'gallery'              => [
                    'class' => GalleryBehavior::className(),
                ],
                'timestamp'            => [
                    'class' => TimestampBehavior::className(),
                ],
            ];
        }
        
        public static function tableName()
        {
            return 'page';
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(PageLang::className(), [ 'page_id' => 'id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasDefaultVariationRelation();
        }
        
        public function getCategories()
        {
            return $this->hasMany(Category::className(), [ 'id' => 'category_id' ])
                        ->viaTable(
                            'page_to_category',
                            [ 'page_id' => 'id' ]
                        );
        }
        
        /**
         * @return string
         */
        public function getRoute()
        {
            return Json::encode(
                [
                    'page/view',
                    'id' => $this->id,
                ]
            );
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getImage()
        {
            return $this->hasOne(Image::className(), [ 'id' => 'image_id' ]);
        }
        
        /**
         * @return array
         */
        public function attributeLabels()
        {
            return [
                'title'       => \Yii::t('core', 'Title'),
                'body'        => \Yii::t('core', 'Body'),
                'updated_at'  => \Yii::t('core', 'Date'),
                'sort'        => \Yii::t('core', 'Sort'),
                'categories'  => \Yii::t('core', 'Categories'),
                'in_menu'     => \Yii::t('core', 'page_in_menu'),
                'in_up_menu'  => \Yii::t('core', 'page_in_up_menu'),
                'image_id'    => \Yii::t('core', 'Image'),
                'categoryIds' => \Yii::t('core', 'Categories'),
            ];
        }
    }