<?php
    
    namespace common\models\partners;
    
    use artbox\core\models\Image;
    use artbox\core\models\Language;
    use yii\db\ActiveQuery;
    use yii\db\ActiveRecord;
    use yii2tech\ar\position\PositionBehavior;
    use yii2tech\ar\variation\VariationBehavior;
    
    /**
     * Class Page
     *
     * @package common\models\speaker
     * @property integer $id
     * @property integer $sort
     * @property boolean $status
     * @property Image   $image

     * @method ActiveQuery  hasDefaultVariationRelation();
     */
    class Partner extends ActiveRecord
    {
        public function rules()
        {
            return [
                [
                    [
                        'sort',
                        'image_id',
                    ],
                    'integer',
                ],

                [
                    [
                        'status',
                    ],
                    'boolean',
                ],
            ];
        }
        
        public function behaviors()
        {
            return [
                'translations'     => [
                    'class'                             => VariationBehavior::className(),
                    'variationsRelation'                => 'languages',
                    'defaultVariationRelation'          => 'language',
                    'variationOptionReferenceAttribute' => 'language_id',
                    'optionModelClass'                  => Language::className(),
                    'defaultVariationOptionReference'   => function () {
                        return Language::getCurrent()->id;
                    },
                    'optionQueryFilter'                 => function (ActiveQuery $query) {
                        $query->where(
                            [
                                'status' => true,
                            ]
                        );
                    },
                ],
                'positionBehavior' => [
                    'class'             => PositionBehavior::className(),
                    'positionAttribute' => 'sort',
                ],
            ];
        }
        
        public static function tableName()
        {
            return 'partner';
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguages()
        {
            return $this->hasMany(PartnerLang::className(), [ 'partner_id' => 'id' ]);
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getLanguage()
        {
            return $this->hasOne(PartnerLang::className(), [ 'partner_id' => 'id' ])
                        ->where(
                            [
                                'language_id' => Language::getCurrent()->id,
                            ]
                        );
        }
        
        /**
         * @return \yii\db\ActiveQuery
         */
        public function getImage()
        {
            return $this->hasOne(Image::className(), [ 'id' => 'image_id' ]);
        }
        
        /**
         * @return array
         */
        public function attributeLabels()
        {
            return [
                'sort'      => \Yii::t('core', 'Sort'),
                'status'    => \Yii::t('core', 'Status'),
                'image_id'  => \Yii::t('core', 'Image'),

            ];
        }
    }