<?php
    
    namespace frontend\controllers;
    
    use artbox\core\models\Feedback;
    use common\models\Customer;
    use common\models\Logo;
    use common\models\partners\Partner;
    use common\models\Settings;
    use common\models\speaker\Speaker;
    use Yii;
    use yii\filters\VerbFilter;
    use yii\swiftmailer\Mailer;
    use yii\web\BadRequestHttpException;
    use yii\web\Controller;
    use yii\web\NotFoundHttpException;
    use yii\web\Response;
    use yii\web\UploadedFile;
    
    /**
     * Site controller
     */
    class SiteController extends Controller
    {
        const THANKS_MAIL_SUBJECT = [
            1 => 'Registration for the Ninth International Forum on Energy for Sustainable Development',
            2 => 'Регистрация на Девятый Международный форум по энергетике для устойчивого развития',
            3 => 'Реєстрація на Дев\'ятий Міжнародний форум з енергетики для сталого розвитку',
            4 => 'Inscription au le neuvième Forum international de l\'énergie pour le développement durable',
        ];
        
        /**
         * @inheritdoc
         */
        public function actions()
        {
            return [
                'error' => [
                    'class' => 'yii\web\ErrorAction',
                ],
            ];
        }
        
        /**
         * @inheritdoc
         */
        public function behaviors()
        {
            return [
                'verbs' => [
                    'class'   => VerbFilter::className(),
                    'actions' => [
                        'feedback' => [ 'post' ],
                    ],
                ],
            ];
        }
        
        /**
         * Displays homepage.
         *
         * @return mixed
         */
        public function actionIndex()
        {
            $speakers = Speaker::find()
                               ->with(
                                   [
                                       'language',
                                       'image',
                                   ]
                               )
                               ->where([ 'status' => true ])
                               ->orderBy('sort')
                               ->all();
            $partners = Logo::find()
                            ->all();
	        $generalPartners  = Partner::find()
		        ->with(
			        [
				        'language',
				        'image',
			        ]
		        )
		        ->where([ 'status' => true ])
		        ->orderBy('sort')
		        ->all();
            return $this->render(
                'index',
                [
                    'speakers' => $speakers,
                    'partners' => $partners,
	                'generalPartners'   => $generalPartners,
                ]
            );
        }
        
        /**
         * Displays contact page.
         *
         * @return mixed
         */
        public function actionContact()
        {
            $contact = new Feedback();
            return $this->render(
                'contact',
                [
                    'contact' => $contact,
                ]
            );
        }
        



        public function actionSpeakers($id){


        	$currentSpeaker = Speaker::findOne($id);
        	if($currentSpeaker == null){
				throw new NotFoundHttpException();
	        }
	        $speakers = Speaker::find()
		        ->with(
			        [
				        'language',
				        'image',
			        ]
		        )
		        ->where([ 'status' => true ])
		        ->orderBy('sort')
		        ->all();
	        $partners = Logo::find()
		        ->all();


	        return $this->render(
		        'speakers',
		        [
			        'speakers'  => $speakers,
			        'partners'  => $partners,
			        'currentSpeaker'   => $currentSpeaker,

		        ]
	        );
        }


        public function actionAbout()
        {
            return $this->render('about');
        }
        
        /**
         * Action to view robots.txt file dinamycli
         *
         * @return string
         */
        public function actionRobots()
        {
            $response = \Yii::$app->response;
            /**
             * @var Settings $settings
             */
            $settings = Settings::find()
                                ->one();
            $temp = tmpfile();
            fwrite($temp, $settings->robots);
            $meta = stream_get_meta_data($temp);
            $response->format = $response::FORMAT_RAW;
            $response->headers->set('Content-Type', 'text/plain');
            return $this->renderFile($meta[ 'uri' ]);
        }
        
        public function actionFeedback()
        {
            Yii::$app->response->format = Response::FORMAT_JSON;
            
            /**
             * @var Mailer $mailer
             */
            $mailer = \Yii::$app->get('smtpmailer');
            $settings = Settings::getInstance();
            
            if (empty(Yii::$app->request->post())) {
                throw new BadRequestHttpException();
            } else {
                $model = new Feedback();
                if ($model->load(Yii::$app->request->post()) && $model->save()) {
                    
                    $mailer->compose(
                        'feedback',
                        [
                            'model' => $model,
                        ]
                    )
                           ->setFrom('energyforum@euromediacompany.com')
                           ->setTo($settings->email)
                           ->setSubject(\Yii::t('app', 'Feedback'))
                           ->send();
                    
                    return [
                        'success' => true,
                        'message' => 'Success message',
                        'alert'   => '<div class="alert alert-success">
            <h3>Success</h3>
            <p>
              Success text
            </p>
          </div>',
                    ];
                } else {
                    return [
                        'success' => false,
                        'error'   => $model->errors,
                    ];
                }
            }
        }
        
        public function actionRegister()
        {
            $model = new Customer();
            if ($model->load(\Yii::$app->request->post()) && $model->acceptance!==0) {
                $model->file = UploadedFile::getInstance($model, 'file');
                if ($model->upload() and $model->save()) {
                    \Yii::$app->session->setFlash(
                        'success',
                        \Yii::t(
                            'app',
                            #'Thanks for request'
	                        'Thanks for request'
                        )
                    );



                    try {
                        $this->mail($model);
                    } catch (\Exception $exception) {
                        \Yii::error($exception->getMessage() . '. On request: ' . $model->id);
                        
                        return $this->redirect([ 'site/index' ]);
                    } catch (\Throwable $throwable) {
                        \Yii::error($throwable->getMessage() . '. On request: ' . $model->id);
                        
                        return $this->redirect([ 'site/index' ]);
                    }
                    
                    return $this->redirect([ 'site/index' ]);
                }
                /*else{
                	die(var_dump($model->errors));
                }*/

            }
            return $this->render(
                'signup',
                [
                    'model' => $model,
                ]
            );
        }
        
        /**
         * @param $model Customer
         */
        public function mail($model)
        {
        	$subject="REGISTRATION__#".$model->id.': '.$model->name;
            \Yii::$app->mailer->compose(
                'request',
                [
                    'model' => $model,
                ]
            )
                              ->setFrom(
                                  [
                                     # 'artboxcore@gmail.com' => 'Artbox Core',
                                      #'energyforum@euromediacompany.com' => 'New mail address1',
                                      'energyforum@euromediacompany.com' =>
	                                      'NINTH INTERNATIONAL FORUM',
                                  ]
                              )
                              ->setTo(
                                  [
//                                      'kennen.md@gmail.com',
	                                   # 'alkhonko@gmail.com',
                                      'energyforum@euromediacompany.com',
		                              'forum@mev.gov.ua',
                                  ]
                              )
	                          ->setBcc(
		                          'kazimirova.artweb@gmail.com'
	                          )
                              ->setSubject($subject)
                              ->attach(\Yii::getAlias('@' . trim($model->image, '/')))
                              ->send();

            \Yii::$app->mailer->compose(
                '_thanks_' . $model->language_id,
                [
                    'phone' => '+380732590821',
                    'email' => 'energyforum@euromediacompany.com',
	                'model' => $model,
                ]
            )
                              ->setFrom(
                                  [
                                      'artboxcore@gmail.com' => 'NINTH INTERNATIONAL FORUM',
                                  ]
                              )
                              ->setTo(
                                  $model->email
                              )
                              ->setSubject(self::THANKS_MAIL_SUBJECT[ (int) $model->language_id ])
                              ->send();
        }
    }
