<?php
    
    /**
     * @var View           $this
     * @var string         $content
     * @var SeoComponent   $seo
     * @var User           $user
     * @var PageCategory[] $pageCategories
     * @var \artbox\core\forms\Module $module;
     */
    
    use artbox\core\components\SeoComponent;
    use artbox\core\helpers\ImageHelper;
    use artbox\core\models\Feedback;
    use artbox\core\models\PageCategory;
    use artbox\core\models\User;
    use common\models\page\Category;
    use common\models\page\Page;
    use common\models\Settings;
    use frontend\assets\AppAsset;
    use artbox\core\components\imagemanager\models\ImageManager;
    use frontend\widgets\ArtboxModalWidget;
    use frontend\widgets\LanguageWidget;
    use yii\bootstrap\Nav;
    use yii\bootstrap\Html;
    use yii\db\ActiveQuery;
    use artbox\core\helpers\Url;
    use yii\db\Query;
    use yii\web\View;
    use yii\widgets\Breadcrumbs;
    
    
    AppAsset::register($this);
    $user = \Yii::$app->user->identity;
    $seo = Yii::$app->get('seo');
    $feedback = new Feedback();
    $settings = Settings::getInstance();
    $controller = Yii::$app->controller;
    $default_controller = Yii::$app->defaultRoute;
    $isHome = ( ( $controller->id === $default_controller ) && ( $controller->action->id === $controller->defaultAction ) ) ? true : false;
    $pageCategories = Category::find()
                                  ->with(
                                      [
                                          'language',
                                          'pages' => function (ActiveQuery $query) {
                                              $query->with(['language', 'alias'])
                                                    ->where(['in_menu' => true])
                                                    ->orderBy([ 'sort' => SORT_ASC ]);
                                          },
                                      ]
                                  )
                                  ->where([ 'status' => true ])
                                  ->orderBy([ 'sort' => SORT_ASC ])
                                  ->all();
    $pages = Page::find()->with(['language', 'alias'])->where(['NOT IN', 'id', (new Query())->select('page_id')->from('page_to_category')->column()])->all();
    $logo = null;
    if ($settings->logo) {
        $logo_img = ImageManager::findOne($settings->logo);
        if ($logo_img) {
            $logo = $logo_img->getImagePathPrivate() ?? $logo;
        }
    }
    
    $this->registerMetaTag(
        [
            'name'    => 'description',
            'content' => $seo->desc,
        ]
    );
    $module = \Yii::$app->getModule('feedback');
    
    if (\Yii::$app->session->hasFlash('success')) {
        $message = \Yii::$app->session->getFlash('success');
        $js = <<<JS
      success("$message");
JS;
        $this->registerJs($js, View::POS_READY);
    }
    $currentLang=\artbox\core\models\Language::getCurrent()->url;


?>

<?php $this->beginPage() ?>
  <!DOCTYPE html>
  <html lang="<?= \Yii::$app->language ?>">
    <head>
      <meta charset="<?= \Yii::$app->charset ?>">
      <meta name="viewport" content="width=device-width, initial-scale=1">
        <?= Html::csrfMetaTags() ?>
      <title><?= Html::encode($seo->title) ?></title>
	<link rel="icon" href="/favicon.ico" type="image/x-icon">
        <?php $this->head() ?>
    </head>
    <body>
        <?php $this->beginBody() ?>
      <!-- Google Analytics -->
      <?php if (!empty($settings->ga_code)) { ?>
      <script>
          (function(i, s, o, g, r, a, m) {
              i[ 'GoogleAnalyticsObject' ] = r;
              i[ r ] = i[ r ] || function() {
                      (i[ r ].q = i[ r ].q || []).push(arguments)
                  }, i[ r ].l = 1 * new Date();
              a = s.createElement(o), m = s.getElementsByTagName(o)[ 0 ];
              a.async = 1;
              a.src = g;
              m.parentNode.insertBefore(a, m)
          })(window, document, 'script', 'https://www.google-analytics.com/analytics.js', 'ga');

          ga('create', '<?=$settings->ga_code?>', 'auto');
          ga('send', 'pageview');
      
      </script>
      <?php } ?>
      <header id="header_" class="section-box-header">
        <section class="first-menu hidden-xs">
          <div class="container">
           <?=\frontend\widgets\LangLinks::widget()?>
          </div>
        </section>
        <section class="logos-titles">
          <div class="container">
            <div class="row">
              <div class="col-xs-12 col-sm-7 col-md-9 logo-title-col">
                <a href="<?=Url::to(['/'])?>" class="logo-title">
                  <span><?=\Yii::t('app', '9F')?></span>
                  <i><?=\Yii::t('app', '12-18')?></i>
                </a>
              </div>
              <div class="hidden-xs col-sm-5 col-md-3 logos-header-wr">
                <a target="_blank" href="https://www.kmu.gov.ua/ua" class="logos-header-1">
                  <img src="/images/logos-1.svg" alt="">
                </a>
<!--                <a target="_blank" href="http://www.un.org/" class="logos-header-1">-->
<!--                  <img src="/images/logos-2.svg" alt="">-->
<!--                </a>-->
                  <div class="logos-header-3">
                      <a target="_blank" href="http://www.unece.org/index.php?id=49144" >
                          <img src="/images/logos-3.svg" height="60" alt="">
                      </a>
                  </div>
              </div>
            </div>
          </div>
        </section>
    
        <section class="section-nav">
          <div class="container">
            <div class="row">
              <div class="col-xs-12 col-sm-9">
                <nav>
                  <ul>
                    <?php foreach ($pageCategories as $category){?>
                    <li>
                        <?php

                        if($category->id==4){
                            ?>

                            <a  target="_blank"
                            <?php if(\Yii::$app->devicedetect->isMobile()){
                                ?>
                                download
                                <?php
                            } ?>
                            ><?=$category->language->title?></a>
                            <?php
                        }
                        else
                            {?>
                                <a  target="_blank"><?=$category->language->title?></a>

                            <?php
                                }
                        ?>

                        <ul>
                          <?php foreach ($category->pages as $page){?>
                            <li><a href="<?=Url::to(['alias' => $page->alias])?>"><?=$page->language->title?></a></li>
                          <?php }?>
                        </ul>
                    </li>
                     <?php }?>
                      <?php foreach ($pages as $page){?>
                        <li><a href="<?=Url::to(['alias' => $page->alias])?>"><?=$page->language->title?></a></li>

                      <?php }?>
                  </ul>
                </nav>
              </div>
          
              <div class="col-xs-12 col-sm-3 header-register-btn-col">
                <div class="menu_mob hidden visible-xs">
                  <div></div>
                  <div></div>
                </div>
                <a class="header-register-btn" href="<?=Url::to(['site/register'])?>">
                    <?=Yii::t('app', 'Register!')?></a>
              </div>
            </div>
          </div>
    
        </section>
    
    
        <div class="mobile-menu-hidden" style="display: none;">
          <div class="close-lang-mob">
           <?=\frontend\widgets\LangLinks::widget(['mobile' => true])?>
            <div class="close-mobile-menu"></div>
          </div>
      
          <div class="mobi-menu-primary">
            <ul class="mobi-menu-primary-ul">
              <li><a >
                      <?=\Yii::t('app','Main');?>
                      </a></li>
              <?php foreach ($pageCategories as $category){ ?>
              <li>
                  <a href="#"><?=$category->language->title?></a>
                  <div class="sub-menu-hidden-mob">
                      <ul>
                          <?php foreach ($category->pages as $page){?>
                            <li><a href="<?=Url::to(['alias' => $page->alias])?>"><?=$page->language->title?></a></li>
                          <?php }?>
                      </ul>
                  </div>
              </li>
    <?php }?>
              <?php foreach ($pages as $page){?>
                <li><a href="<?=Url::to(['alias' => $page->alias])?>"><?=$page->language->title?></a></li>

              <?php }?>
            </ul>
          </div>
        </div>
  
      </header>
  
      <!-- #content должен быть в main.php -->
      <div id="content_" class="section-box-content">
        <?php if (!empty($this->params['breadcrumbs'])){?>
        <section class="section-breadcrumb">
          <div class="container">
            <div class="row">
              <div class="col-xs-12 col-sm-12 breadcrumb-wrapp">
                  <?= Breadcrumbs::widget(
                      [
                          'links'    => isset($this->params[ 'breadcrumbs' ]) ? $this->params[ 'breadcrumbs' ] : [],
                          'homeLink' => [
                              'label' => \Yii::t('app', 'Main'),
                              'url'   => Url::home(false, 'common\components\Languages'),
                          ],
                      ]
                  ) ?>
                </ul>
              </div>
            </div>
          </div>
        </section>
    <?php } ?>
        <!-- start content -->
        <?=$content?>
        <!-- end content -->
  
      </div>
  
      <footer id="footer_" class="section-box-footer" >


    
        <div class="section-box studio_footer">
          <div class="container">
            <div class="row">
              <div class="col-xs-12 col-sm-12 footer-menu-col">
                <ul class="li_to_upper">
                  <li><a href="<?=Url::to(['site/register'])?>">
                          <?=Yii::t('app', 'Register!')?></a></li>
                </ul>
              </div>
            </div>
            <div class="row row-footer-txt">
              <div class="col-xs-12 col-sm-6 col-sm-push-6">
                <div style="display: none" class="seti-wrapp">
                  <div class="seti-txt"><?=\Yii::t('app', 'We in socials')?>:</div>
                  <div class="seti-list">
                    <ul>
                      <li><a target="_blank" class="seti-1" href="#"><img src="/images/s/10.svg" width="10" alt=""></a></li>
                      <li><a target="_blank" class="seti-2" href="#"><img src="/images/s/11.svg" width="22" alt=""></a></li>
                      <li><a target="_blank" class="seti-3" href="#"><img src="/images/s/12.svg" width="22" alt=""></a></li>
                      <li><a target="_blank" class="seti-4" href="#"><img src="/images/s/13.svg" width="24" alt=""></a></li>
                      <li><a target="_blank" class="seti-5" href="#"><img src="/images/s/14.svg" width="18" alt=""></a></li>
                    </ul>
                  </div>
                </div>
              </div>
              <div class="col-xs-12 col-sm-6 col-sm-pull-6">
                <div class="footer-txt">
                  <span><?=\Yii::t('app', '9F')?></span>
                </div>
              </div>
            </div>
            <div class="row">
              <div class="col-xs-12 col-sm-6">
                <div class="copyright">2018 © <i class="hidden">
                        <?=\Yii::t('app','All rights reserved')?>.</i></div>
              </div>
                <div class="col-xs-12 col-sm-6">
                    <div class="artweb-wr">
                        <a target="_blank" href="http://artweb.ua/"><?=\Yii::t('app','studio-link')?></a>
                        <div class="artweb-img">
                            <a target="_blank" href="http://artweb.ua/">
                                <div class="ico-spr ico-artweb-logo"></div>
                            </a>
                        </div>
                    </div>
                </div>
            </div>
          </div>
        </div>


        <div style="display: none;" class="btn_up"></div>

      </footer>


      <div id="overlay" style="display: none;"></div>
      <div id="overlay-catalog" style="display: none;"></div>
      <div id="callback" class="forms_" style="display: none;">
        <span id="modal_close"></span>
        <div class="style form-title">
	        <?=\Yii::t('app','Callback');?>
        </div>
        <form action="">
          <div class="input-wr">
            <label for="inp-11"><?=\Yii::t('app','Name')?></label>
            <input id="inp-11" type="text">
          </div>
          <div class="input-wr phones_mask">
            <label for="inp-22"><?=\Yii::t('app','Phone')?></label>
            <input id="inp-22" type="text">
          </div>
          <div class="input-wr">
            <label for="inp-33"><?=\Yii::t('app','Message')?></label>
            <textarea id="inp-33" name="" cols="30" rows="10"></textarea>
          </div>
          <div class="button-wr">
            <button type="submit"><?=\Yii::t('app','Send')?></button>
          </div>
        </form>
      </div>
      <div id="success_form" style="display: none;">
        <span id="modal_close"></span>
        <div class="txt-success"><span>
                <?=\Yii::t('app','Thanks for request')?>
                </span>
            <p><?=\Yii::t('app','We call you later')?>
                </p></div>
      </div>
        <?php $this->endBody() ?>
    </body>
  </html>
<?php $this->endPage() ?>
